==> sweepinconnect-2.0.3-sources.jar: com/proximities/sdk/activities/PermissionDialogActivity.java <==
package com.proximities.sdk.activities;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;

import com.proximities.sdk.ProximitiesConfig;
import com.proximities.sdk.R;
import com.proximities.sdk.util.ProximitiesConstants;
import com.proximities.sdk.util.SCSdkNotInitializeException;
import com.proximities.sdk.util.Utils;

/**
 * Created by william on 14/10/15.
 */
public class PermissionDialogActivity extends AppCompatActivity{

    private static final int MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION = 5;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if(ContextCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED){
            ActivityCompat.requestPermissions(PermissionDialogActivity.this, new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                    MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION);
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        switch (requestCode) {
            case MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION: {
                if (grantResults.length > 0 && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    finish();
                    if(ProximitiesConfig.getOnAccessLocationListener() != null){
                        ProximitiesConfig.getOnAccessLocationListener().onAccessLocationGranted();
                    }
                } else {
                    finish();
                    if(ProximitiesConfig.getOnAccessLocationListener() != null){
                        ProximitiesConfig.getOnAccessLocationListener().onAccessLocationDenied();
                    }
                }
            }
        }
    }

}

==> sweepinconnect-2.0.7-sources.jar: com/proximities/sdk/activities/PermissionDialogActivity.java <==
package com.proximities.sdk.activities;

import android.Manifest;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;

import com.proximities.sdk.ProximitiesConfig;
import com.proximities.sdk.R;
import com.proximities.sdk.util.ProximitiesConstants;
import com.proximities.sdk.util.SCSdkNotInitializeException;
import com.proximities.sdk.util.Utils;

/**
 * Created by william on 14/10/15.
 */
public class PermissionDialogActivity extends AppCompatActivity{

    private static final int MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION = 5;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (android.os.Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
        if(ContextCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED){
            ActivityCompat.requestPermissions(PermissionDialogActivity.this, new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                    MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION);
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        switch (requestCode) {
            case MY_PERMISSIONS_REQUEST_ACCESS_FINE_LOCATION: {
                if (grantResults.length > 0 && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    finish();
                    if(ProximitiesConfig.getOnAccessLocationListener() != null){
                        ProximitiesConfig.getOnAccessLocationListener().onAccessLocationGranted();
                    }
                } else {
                    finish();
                    if(ProximitiesConfig.getOnAccessLocationListener() != null){
                        ProximitiesConfig.getOnAccessLocationListener().onAccessLocationDenied();
                    }
                }
            }
        }
    }

}
